# Notification Server

This is a simple base implementation of a Notification Server to handle notifications from a CSE. Verification requests are always acknowledged, and notifications are just printed to the console.

The server normally listens on port 9999. This can be changed by specifying another value to the *port* variable at the beginning of the file.

Start the server by running the command:

		python3 notificationServer.py